package ch.hslu.edu.enapp.webshop.control;

import com.ibm.jpa.web.JPAManager;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import com.ibm.jpa.web.NamedQueryTarget;
import com.ibm.jpa.web.Action;
import javax.persistence.PersistenceUnit;
import ch.hslu.edu.enapp.webshop.entity.Customer;
import java.util.List;
import javax.persistence.Query;

@SuppressWarnings("unchecked")
@JPAManager(targetEntity = ch.hslu.edu.enapp.webshop.entity.Customer.class)
public class CustomerManager {

	@PersistenceUnit
	private EntityManagerFactory emf;

	public CustomerManager() {
	
	}

	private EntityManager getEntityManager() {
		return emf.createEntityManager();
	}

	@Action(Action.ACTION_TYPE.CREATE)
	public void createCustomer(Customer customer) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.persist(customer);
		} finally {
			em.close();
		}
	}

	@Action(Action.ACTION_TYPE.DELETE)
	public void deleteCustomer(Customer customer) throws Exception {
		EntityManager em = getEntityManager();
		try {
			customer = em.merge(customer);
			em.remove(customer);
		} finally {
			em.close();
		}
	}

	@Action(Action.ACTION_TYPE.UPDATE)
	public void updateCustomer(Customer customer) throws Exception {
		EntityManager em = getEntityManager();
		try {
			customer = em.merge(customer);
		} finally {
			em.close();
		}
	}

	@Action(Action.ACTION_TYPE.FIND)
	public Customer findCustomerById(int id) {
		Customer customer = null;
		EntityManager em = getEntityManager();
		try {
			customer = (Customer) em.find(Customer.class, id);
		} finally {
			em.close();
		}
		return customer;
	}

	@Action(Action.ACTION_TYPE.NEW)
	public Customer getNewCustomer() {
	
		Customer customer = new Customer();
	
		return customer;
	}

	@NamedQueryTarget("getCustomerByNAVCustomer")
	public List<Customer> getCustomerByNAVCustomer(String NAVCustomer) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByNAVCustomer");
			query.setParameter("NAVCustomer", NAVCustomer);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByUsername")
	public List<Customer> getCustomerByUsername(String username) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByUsername");
			query.setParameter("username", username);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByPassword")
	public List<Customer> getCustomerByPassword(String password) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByPassword");
			query.setParameter("password", password);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByName")
	public List<Customer> getCustomerByName(String name) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByName");
			query.setParameter("name", name);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByEmail")
	public List<Customer> getCustomerByEmail(String email) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByEmail");
			query.setParameter("email", email);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByAddress")
	public List<Customer> getCustomerByAddress(String address) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByAddress");
			query.setParameter("address", address);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerById")
	public List<Customer> getCustomerById(int id) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerById");
			query.setParameter("id", id);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomer")
	public List<Customer> getCustomer() {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomer");
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

}