package ch.hslu.edu.enapp.webshop.jsf;

import java.io.IOException;
import java.io.Serializable;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.faces.event.ActionEvent;
import javax.inject.Named;

import ch.hslu.edu.enapp.webshop.common.CustomerServiceRemote;
import ch.hslu.edu.enapp.webshop.common.dto.CustomerDTO;

@Named
@SessionScoped
public class UserSession implements Serializable {
	private static final long serialVersionUID = 1L;

	private CustomerDTO customer;
	private String name;
	private String address;
	private String email;
	private String pwdold;
	private String pwd1;
	private String pwd2;
	private boolean updateSuccess = false;
	private String updateStatus;

	@EJB
	private CustomerServiceRemote customerService;

	@PostConstruct
	public void init() {
		this.customer = customerService.getCustomer();
		// System.out.println("UserSession: " + customer.getUsername() + " (Id: " + customer.getId() + ")");
	}

	public void setName(final String newName) {
		this.name = newName;
	}

	public void setAddress(final String newAddress) {
		this.address = newAddress;
	}

	public void setEmail(final String newEmail) {
		this.email = newEmail;
	}

	public void setPwdold(final String newPwdOld) {
		this.pwdold = newPwdOld;
	}

	public void setPwd1(final String newPwd1) {
		this.pwd1 = newPwd1;
	}

	public void setPwd2(final String newPwd2) {
		this.pwd2 = newPwd2;
	}

	public String getPwdold() {
		return "";
	}

	public String getPwd1() {
		return "";
	}

	public String getPwd2() {
		return "";
	}

	public String updateCustomer() {
		if (pwdold == null) {
			pwdold = "";
		}
		if (pwd1 == null) {
			pwd1 = "";
		}
		if (pwd2 == null) {
			pwd2 = "";
		}

		// System.out.println("Update Customer (" + customer.getId() + ")");
		// System.out.println("     Name: " + this.name);
		// System.out.println("  Address: " + this.address);
		// System.out.println("    EMail: " + this.email);
		// System.out.println("  PWD Old: " + this.pwdold);
		// System.out.println("    PWD 1: " + this.pwd1);
		// System.out.println("    PWD 2: " + this.pwd2);

		updateSuccess = true;
		updateStatus = "";
		if (pwdold.length() > 0) {
			if (customer.getPassword().equals(pwdold)) {
				if (pwd1.length() > 2) {
					if (pwd1.equals(pwd2)) {
						customer.setPassword(pwd1);
						// System.out.println("Change PWD...");
						updateStatus = "Password has changed! Please logout and login. ";
					} else {
						updateSuccess = false;
						updateStatus = "Please confirm the new Password.";
					}
				} else {
					updateSuccess = false;
					updateStatus = "New password must contain at least 3 chars!";
				}
			} else {
				updateSuccess = false;
				updateStatus = "Wrong Password!";
			}
		}

		if (updateSuccess && (name.length() > 0) && (address.length() > 0) && (email.length() > 0)) {
			// update only if all fields filled out
			customer.setName(name);
			customer.setAddress(address);
			customer.setEmail(email);

			updateSuccess = customerService.updateCustomer(customer);
			if (updateSuccess) {
				// success
				updateStatus += "Customer successfully updated!";
			} else {
				// error
				updateStatus = "Update Customer failed...";
			}
		} else {
			if (updateSuccess) { // else wrong new password, see above
				updateSuccess = false;
				updateStatus = "Please fill out all fields!";
			}
		}

		return "/secured/account.xhtml?update=done&faces-redirect=true";
	}

	public boolean isUpdateSuccess() {
		return updateSuccess;
	}

	public String getUpdateStatus() {
		return updateStatus;
	}

	public String getUsername() {
		return customer.getUsername();
	}

	public String getName() {
		return customer.getName();
	}

	public String getAddress() {
		return customer.getAddress();
	}

	public String getEmail() {
		return customer.getEmail();
	}

	public String getNameWithLogin() {
		return customer.getName() + " (" + customer.getUsername() + ")";
	}

	public CustomerDTO getCustomer() {
		return customer;
	}

	public int getCustomerId() {
		return customer.getId();
	}

	public void logout(final ActionEvent evt) throws IOException {
		final ExternalContext ec = FacesContext.getCurrentInstance().getExternalContext();
		ec.invalidateSession();

		// final FacesMessage message = new
		// FacesMessage(FacesMessage.SEVERITY_INFO, "Logout successful", null);
		// FacesContext.getCurrentInstance().addMessage(null, message);

		ec.redirect(ec.getRequestContextPath() + "/ibm_security_logout?logoutExitPage=/index.xhtml");
	}

	public boolean isAdmin() {
		return customerService.isAdmin(customer);
	}

}
