package ch.hslu.edu.enapp.webshop.admin.jsf;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.inject.Named;

import ch.hslu.edu.enapp.webshop.common.PurchaseServiceRemote;
import ch.hslu.edu.enapp.webshop.common.dto.PurchaseDTO;
import ch.hslu.edu.enapp.webshop.common.dto.PurchaseitemDTO;

@Named
@SessionScoped
public class Purchase implements Serializable {
	private static final long serialVersionUID = 1L;

	@EJB
	private PurchaseServiceRemote purchaseService;

	public List<PurchaseDTO> getAllOrders() {
		final ArrayList<PurchaseDTO> list = (ArrayList<PurchaseDTO>) purchaseService.getAllPurchaseHistory();
		// sort List based on Date descending
		Collections.sort(list, new Comparator<PurchaseDTO>() {
			@Override
			public int compare(final PurchaseDTO p1, final PurchaseDTO p2) {
				return p2.getDatetime().compareTo(p1.getDatetime());
			}
		});
		return list;
	}

	public PurchaseDTO getPurchaseById(final int purchaseId) {

		return purchaseService.getPurchaseById(purchaseId);
	}

	public List<PurchaseitemDTO> getPurchaseitemsByPurchaseId(final int purchaseId) {
		return purchaseService.getPurchaseitemsByPurchaseId(purchaseId);
	}

	public BigDecimal getTotalItemsOfPurchase(final int purchaseId) {
		BigDecimal totalItems = BigDecimal.ZERO;
		final List<PurchaseitemDTO> purchaseitems = getPurchaseitemsByPurchaseId(purchaseId);
		for (final PurchaseitemDTO purchaseitem : purchaseitems) {
			totalItems = totalItems.add(purchaseitem.getQuantity());
		}
		return totalItems;
	}

	public BigDecimal getTotalPriceOfPurchase(final int purchaseId) {
		BigDecimal totalPrice = BigDecimal.ZERO;
		final List<PurchaseitemDTO> purchaseitems = getPurchaseitemsByPurchaseId(purchaseId);
		for (final PurchaseitemDTO purchaseitem : purchaseitems) {
			totalPrice = totalPrice.add(purchaseitem.getQuantity().multiply(purchaseitem.getUnitprice()));
		}
		return totalPrice;
	}
}